@@ -76,6 +76,8 @@ rGIG<-function(x,lambda,delta,gamma){
 }
 
 dGIG<-function(x,lambda,delta,gamma){
+    if(x <= 0)
+    stop("x must be positive")
     if((delta < 0)||(gamma<0)){
         stop("delta and gamma must be nonnegative.")
     }
@@ -116,7 +118,7 @@ rGH<-function(x,lambda,alpha,beta,delta,mu,Lambda){
     }
     
     ## univariate case
-    if(is.na(Lambda)){
+    if(any(is.na(Lambda))){
         if(length(mu)!=1 || length(beta)!=1){
             stop("Error: wrong input dimension.")
         }
@@ -193,7 +195,7 @@ dGH<-function(x,lambda,alpha,beta,delta,mu,Lambda){
     }
     
     ## univariate case
-    if(is.na(Lambda)){
+    if(any(is.na(Lambda))){
         if(length(mu)!=1 || length(beta)!=1){
             stop("Error: wrong input dimension.")
         }
@@ -274,7 +276,7 @@ rvgamma <- function(x,lambda,alpha,beta,mu,Lambda){
   if(missing(Lambda))
    Lambda <- NA
   
-  if(is.na(Lambda)){
+  if(any(is.na(Lambda))){
     ## univariate case
     if(length(mu)!=1 || length(beta)!=1){
       stop("Error: wrong input dimension.")
@@ -348,7 +350,7 @@ dvgamma <- function(x,lambda,alpha,beta,mu,Lambda){
   }
   if(missing(Lambda))
     Lambda <- NA
-  if(is.na(Lambda)){
+  if(any(is.na(Lambda))){
     ## univariate case
     if(length(mu)!=1 || length(beta)!=1){
       stop("Error: wrong input dimension.")
@@ -408,6 +410,8 @@ rIG <- function(x,delta,gamma){
 
 
 dIG <- function(x,delta,gamma){
+  if(x <= 0)
+    stop("x must be positive")
 	if( delta <= 0 )
     stop("delta must be positive.")
 	if( gamma <= 0 )
@@ -436,7 +440,7 @@ rNIG <- function(x,alpha,beta,delta,mu,Lambda){
   if(missing(Lambda))
    Lambda <- NA
 
-  if(any(is.na(Lambda)==TRUE) & length(Lambda)==1){
+  if(any(is.na(Lambda)) & length(Lambda)==1){
     ## univariate case
     gamma <- sqrt(alpha^2 - beta^2)
     if(gamma <0){
@@ -504,7 +508,7 @@ dNIG <- function(x,alpha,beta,delta,mu,Lambda){
     stop("delta must be positive.")
   if(missing(Lambda))
     Lambda <- NA
-  if(is.na(Lambda)){
+  if(any(is.na(Lambda))){
     #univraiate case
     if(length(beta)>1||length(mu)>1)
       stop("beta and mu must be numeric")
@@ -638,7 +642,7 @@ rnts<-function(x,alpha,a,b,beta,mu,Lambda){
   if( b <= 0 )
     stop("b must be positive value.")
   
-  if(is.na(Lambda)){
+  if(any(is.na(Lambda))){
     ## univariate case
     if(length(mu)!=1 || length(beta)!=1){
       stop("Error: wrong input dimension.")
