@@ -1,5 +1,7 @@
+#include <R.h>
 #include <Rinternals.h>
 #include <math.h>
+#include <float.h>
 
 void ctsubsampling(double *znum, double *ztime, int *frequency, int *nsparse, int *n, double *grid, double *result)
 {
@@ -380,7 +382,7 @@ void HYcrosscorr(int *gridL, int *xL, int *yL, double *grid, double *xtime,
         }else{
             s = 0;
         }
-
+        
         
         value[i] = B/sqrt((A + s)*(C + s));
         
@@ -388,6 +390,126 @@ void HYcrosscorr(int *gridL, int *xL, int *yL, double *grid, double *xtime,
 }
 
 
+void HYcrosscov2(int *gridL, int *xL, int *yL, double *grid, double *xtime,
+                 double *ytime, double *dX, double *dY, double *value)
+{
+    int i, j, I, J;
+    double *ytime2;
+    
+    for (j = 0; j < *xL; j++) {
+        xtime[j] = round(xtime[j]);
+    }
+    
+    for(i = 0; i < *gridL; i++){
+        
+        ytime2 = (double *)malloc(sizeof(double) * (*yL));
+        
+        for(j = 0; j < *yL; j++){
+            ytime2[j] = round(ytime[j] + grid[i]);
+        }
+        
+        I = 0;
+        J = 0;
+        
+        /* Checking Starting Point */
+        while((I < (*xL-1)) && (J < (*yL-1))){
+            if(xtime[I] >= ytime2[J + 1]){
+                J++;
+            }else if(xtime[I + 1] <= ytime2[J]){
+                I++;
+            }else{
+                break;
+            }
+        }
+        
+        /* Main Component */
+        while((I < (*xL-1)) && (J < (*yL-1))) {
+            value[i] += dX[I] * dY[J];
+            if(xtime[I + 1] > ytime2[J + 1]){
+                J++;
+            }else if(xtime[I + 1] < ytime2[J + 1]){
+                I++;
+            }else{
+                I++;
+                J++;
+            }
+        }
+        
+        free(ytime2);
+    }
+}
+
+
+void HYcrosscorr2(int *gridL, int *xL, int *yL, double *grid, double *xtime,
+                  double *ytime, double *dX, double *dY,
+                  double *xvol, double *yvol, double *value)
+{
+    int i, j, I, J;
+    double A, B, C, s;
+    double *ytime2;
+    
+    for (j = 0; j < *xL; j++) {
+        xtime[j] = round(xtime[j]);
+    }
+    
+    for(i = 0; i < *gridL; i++){
+        
+        ytime2 = (double *)malloc(sizeof(double) * (*yL));
+        
+        for(j = 0; j < *yL; j++){
+            ytime2[j] = round(ytime[j] + grid[i]);
+        }
+        
+        I = 0;
+        J = 0;
+        
+        /* Checking Starting Point */
+        while((I < (*xL-1)) && (J < (*yL-1))){
+            if(xtime[I] >= ytime2[J + 1]){
+                J++;
+            }else if(xtime[I + 1] <= ytime2[J]){
+                I++;
+            }else{
+                break;
+            }
+        }
+        
+        /* Main Component */
+        while((I < (*xL-1)) && (J < (*yL-1))) {
+            value[i] += dX[I] * dY[J];
+            if(xtime[I + 1] > ytime2[J + 1]){
+                J++;
+            }else if(xtime[I + 1] < ytime2[J + 1]){
+                I++;
+            }else{
+                I++;
+                J++;
+            }
+        }
+        
+        /* Positive semi-definite correction */
+        A = (*xvol)*(*xvol) + value[i]*value[i];
+        B = (*xvol + *yvol)*value[i];
+        C = (*yvol)*(*yvol) + value[i]*value[i];
+        
+        /* correct a bug (2016-06-30) */
+        /* s = sqrt(A*C-B*B); */
+        s = A*C-B*B;
+        if(s > 0){
+            s = sqrt(s);
+        }else{
+            s = 0;
+        }
+        
+        
+        value[i] = B/sqrt((A + s)*(C + s));
+        
+        free(ytime2);
+    }
+}
+
+
+
 void hyavar(double *xtime, double *ytime, int *xlength, int *ylength,
             double *x, double *y, int *N, double *h, double *result)
 {
@@ -546,6 +668,10 @@ void hycrossavar(double *grid, double *xtime, double *ytime, int *gridL, int *xl
     int mu[*N], w[*N], q[*N], r[*N];
     double rtimes[*N], Sigma11[*N], Sigma12[*N], Sigma22[*N], H1[*N], H2[*N], H12[*N], H3[*N], dS2[*N], dxdy[*N], tmptime[*ylength];
     
+    for(i = 0; i < *xlength; i++){
+      xtime[i] = round(xtime[i]);
+    }
+    
     for (k = 0; k < *gridL; k++) {
         
         for(j = 0; j < *ylength; j++){
